@@ -76,7 +76,10 @@ def dict_iter(d, delimiter='.'):
                     yield (delimiter.join([k, ki]), vi)
         
         else:
-            yield (k, v)
+            if delimiter is None:
+                yield ((k,), v)
+            else:
+                yield (k, v)
             
 def dict_get(d, k, delimiter='.'):
     if delimiter is None:
